@@ -1,8 +1,8 @@
-from .store import Store
-from .errors import StoreError, CredentialsNotFound
 from .constants import (
     DEFAULT_LINUX_STORE,
     DEFAULT_OSX_STORE,
     DEFAULT_WIN32_STORE,
     PROGRAM_PREFIX,
 )
+from .errors import CredentialsNotFound, StoreError
+from .store import Store
